<?php



/**
 * Implementation of hook_drush_help().
 */
function browsermob_drush_help($section) {
  switch ($section) {
    case 'meta:browsermob:title':
      return dt('Browsermob commands');
  }
}

/**
 * Implementation of hook_drush_command().
 */
function browsermob_drush_command() {
  $items['browsermob-users'] = array(
    'description' => 'Print user information as javascript variables for using in Browsermob scripts.',
    'arguments' => array(
      'num_users' => 'Number of users to list',
    ),
    'options' => array(
      'password' => 'Reset the passwords of all users to this.',
    ),
    'aliases' => array('bmusers'),
  );
  $items['browsermob-import-db'] = array(
    'arguments' => array(
      'sqldump' => 'A gzipped results database from a load test',
      'id' => 'A browsermob test id',
      'name' => 'A browsermob test name',
    ),
  );
  return $items;
}

function drush_browsermob_users($num_users = INF) {
  $accounts = array();
  $count = 0;
  switch(drush_drupal_major_version()) {
    case 6:
      // TODO
      break;
    case 7:
    case 8:
      foreach (entity_load('user') as $user) {
        if ($user->uid > 2 && $count <= $num_users) {
          $accounts[] = $user->name;
          $count++;
        }
      }
      break;
  }

  if ($pass = drush_get_option('password', FALSE)) {
    $confirm = drush_confirm(dt('You are about to reset passwords to !pass. Do you want to continue?', array('!pass' => $pass)));
    // Update each user's password so they are all the same.
    drush_set_option('password', $pass);
    drush_set_option('backend', TRUE);
    foreach ($accounts as $name) {
      drush_invoke('user-password', array($name));
    }
  }
  else {
    // User can fill in later if reset is not used.
    $pass = '';
  }

  drush_print(browsermob_print_javascript($accounts, $pass));
}

function browsermob_print_javascript($accounts, $password) {
  $user_json = json_encode($accounts);
  $output = <<<EOF

    var drupalAccounts = $user_json;
    var drupalUser = drupalAccounts[Math.floor(Math.random() * drupalAccounts.length)];
    var drupalPass = '$password';
EOF;
  return $output;
}

function drush_browsermob_import_db($sqldump, $loadtest_id = NULL, $loadtest_name = NULL) {
  $loadtest_id = $loadtest_id?: '1234';
  // Generate the import command
  $import_command = _drush_sql_connect();
  switch (_drush_sql_get_scheme()) {
  case 'mysql':
    $import_command .= ' --silent';
    break;
  case 'pgsql':
    $import_command .= ' -q';
    break;
  }
  if (drush_shell_exec(sprintf('gzip -t "%s"', $sqldump))) {
    $import_exec = 'gunzip -c ';
  }
  else {
    $import_exec = 'cat ';
  }
  $import_exec .= $sqldump . '| ' . $import_command;

  drush_op_system($import_exec);

  // Insert a new record for this db.
  db_query("INSERT INTO {browsermob_loadtests} (loadtest_id, loadtest_name) VALUES (:loadtest_id, :loadtest_name)", array(':loadtest_id' => $loadtest_id, ':loadtest_name' => $loadtest_name));

  // Copy rows from temporary tables over to this module's.
  $queries = array();
  $queries[] = "INSERT INTO {browsermob_name_value_pairs} (loadtest_id,id,tx_id,step_id,name,value)
    SELECT :loadtest_id,id,tx_id,step_id,name,value
    FROM name_value_pairs";
  $queries[] = "INSERT INTO {browsermob_step} (loadtest_id,bytes,end_time,label,obj_count,start_time,step,step_id,time_active,time_paused,tx_id)
    SELECT :loadtest_id,bytes,UNIX_TIMESTAMP(end_time),label,obj_count,UNIX_TIMESTAMP(start_time),step,step_id,time_active,time_paused,tx_id
    FROM step";
  $queries[] = "INSERT INTO {browsermob_object} (loadtest_id,bytes,domain,end_time,err_msg,host,method,obj_id,obj_num,path,partial_url_md5,protocol,resolved_ip_addr,start_time,status_code,step_id,time_active,blocked_time,dns_lookup_time,connect_time,ssl_handshake_time,send_time,time_to_first_byte,receive_time,tx_id,url)
    SELECT :loadtest_id,bytes,domain,UNIX_TIMESTAMP(end_time),err_msg,host,method,obj_id,obj_num,path,partial_url_md5,protocol,resolved_ip_addr,UNIX_TIMESTAMP(start_time),status_code,step_id,time_active,blocked_time,dns_lookup_time,connect_time,ssl_handshake_time,send_time,time_to_first_byte,receive_time,tx_id,url
    FROM object";
  $queries[] = "INSERT INTO {browsermob_tx} (loadtest_id,bytes,end_time,err_line_num,err_msg,err_screenshot_id,instance_id,obj_count,script_id,script_name,source_ip_addr,start_time,step_count,success,time_active,time_paused,tx_id,user_num)
    SELECT :loadtest_id,bytes,UNIX_TIMESTAMP(end_time),err_line_num,err_msg,err_screenshot_id,instance_id,obj_count,script_id,script_name,source_ip_addr,UNIX_TIMESTAMP(start_time),step_count,success,time_active,time_paused,tx_id,user_num
    FROM tx";

  foreach ($queries as $query) {
    db_query($query, array(':loadtest_id' => $loadtest_id));
  }
}
